@@ -35,4 +35,14 @@ RUN_FILE_CMD = {
 }
 DEFAULT_RUN_FILE_CMD = u'%run "{path}"'
 DEFAULT_RUN_DEBUG_CMD = None
+RUN_SYSTEM_CMD = {
+    u'ir': 'system("{cmd}")',
+    u'bash': '{cmd}'
+}
+DEFAULT_RUN_SYSTEM_CMD = u'!{cmd}'
 TRANSPARENT_KERNELS = [u'python', u'python2', u'python3']
+PID_CMD = {
+    u'python': u'os.getpid()',
+    u'python2': u'os.getpid()',
+    u'python3': u'os.getpid()'
+}
